@@ -21,7 +21,6 @@ use PDF::Imposition;
 use Text::Amuse;
 use Text::Amuse::Functions qw/muse_fast_scan_header/;
 
-
 =encoding utf8
 
 =head1 NAME
@@ -407,6 +406,7 @@ sub pdf {
     my $self = shift;
     my $source = $self->name . '.tex';
     my $output = $self->name . '.pdf';
+    my $logfile = $self->name . '.log';
     unless (-f $source) {
         $self->tex;
     }
@@ -447,6 +447,16 @@ sub pdf {
             }
         }
     }
+    if (-f $logfile) {
+        open (my $fh, '<:encoding(UTF-8)', $logfile)
+          or $self->log_fatal("Couldn't open $logfile $!");
+        while (my $line = <$fh>) {
+            if ($line =~ m/missing character/i) {
+                $self->log_info($line);
+            }
+        }
+        close $fh;
+    }
     return $output;
 }
 
